@@ -1,5 +1,5 @@
 
-from .iterable import tally, counts, counts_by
+from .iterable import tally, counts, counts_by, group_by, gather_by
 from .indexing import first, last, rotate_left, rotate_right, partition
 from .numbertests import even_q, odd_q
 from .nesting import nest_while_list, nest_while, nest, nest_list
